@@ -766,7 +766,6 @@ def PerovskiteTypeRhombohedral(aa,ab,ac,a,ang):
     lb.append(ac,[0.,0.5,0.5])
     lb.append(ac,[0.5,0.,0.5])
 
-    #create lattice vectors alpha=beta=90 gamma=120
     ca = numpy.cos(numpy.radians(ang))
     cb = numpy.cos(numpy.radians(ang))
     cg = numpy.cos(numpy.radians(ang))
@@ -780,3 +779,32 @@ def PerovskiteTypeRhombohedral(aa,ab,ac,a,ang):
     l = Lattice(a1,a2,a3,base=lb)
 
     return l
+
+
+def GeTeRhombohedral(aa,ab,a,ang,x=0.237):
+    #create lattice base
+    lb = LatticeBase()
+    lb.append(aa,[0.-x,0.-x,0.-x])
+    lb.append(aa,[0.5-x,0.5-x,0.0-x])
+    lb.append(aa,[0.5-x,0.-x,0.5-x])
+    lb.append(aa,[0.0-x,0.5-x,0.5-x])
+    lb.append(ab,[0.+x,0.+x,0.+x])
+    lb.append(ab,[0.5+x,0.5+x,0.0+x])
+    lb.append(ab,[0.5+x,0.+x,0.5+x])
+    lb.append(ab,[0.0+x,0.5+x,0.5+x])
+
+    #create lattice vectors
+    ca = numpy.cos(numpy.radians(ang))
+    cb = numpy.cos(numpy.radians(ang))
+    cg = numpy.cos(numpy.radians(ang))
+    sa = numpy.sin(numpy.radians(ang))
+    sb = numpy.sin(numpy.radians(ang))
+    sg = numpy.sin(numpy.radians(ang))
+
+    a1 = a*numpy.array([1,0,0],dtype=numpy.double)
+    a2 = a*numpy.array([cg,sg,0],dtype=numpy.double)
+    a3 = a*numpy.array([cb , (ca-cb*cg)/sg , numpy.sqrt(1-ca**2-cb**2-cg**2+2*ca*cb*cg)/sg],dtype=numpy.double)
+
+    l = Lattice(a1,a2,a3,base=lb)
+
+    return l    
